@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-09-13 16:49:46
-@LastEditTime: 2022-07-18 13:51:04
+@LastEditTime: 2022-08-16 13:55:59
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -446,13 +446,12 @@ class ShakeshopNotifyHandler(FrameBaseHandler):
                         act_info_model = ActInfoModel(context=self)
                         act_info_dict = act_info_model.get_cache_dict(order_by="id desc")
                         if act_info_dict:
-                            frame_base_model = FrameBaseModel(context=self)
-                            user_info_model = UserInfoModel(sub_table=frame_base_model.get_business_sub_table("user_info_tb", {"act_id": act_info_dict["id"], "user_id": 0}), context=self)
+                            user_info_model = UserInfoModel(context=self)
                             user_info_dict = user_info_model.get_cache_dict("act_id=%s and open_id=%s", limit="1", order_by="id desc", params=[act_info_dict["id"],open_id])
                             if user_info_dict:
                                 tiktok_goods_id_list = []
                                 if asset_type == 3:
-                                    price_base_model = PriceBaseModel(context=self.context)
+                                    price_base_model = PriceBaseModel(context=self)
                                     price_gear_dict_list,total = price_base_model.get_price_gear_list(user_info_dict["app_id"], user_info_dict["act_id"], 100, 0)
                                     for price_gear_dict in price_gear_dict_list:
                                         tiktok_goods_id_list.append(price_gear_dict["goods_id"])
