@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:52:51
-@LastEditTime: 2021-12-21 10:27:54
+@LastEditTime: 2022-06-14 16:46:28
 @LastEditors: HuangJianYi
 @Description: 用户模块
 """
@@ -76,21 +76,21 @@ class UpdateUserStatusHandler(ClientBaseHandler):
     """
     :description: 更新用户状态
     """
-    @filter_check_params("act_id,tb_user_id")
+    @filter_check_params(check_user_code=True)
     def get_async(self):
         """
         :description: 更新用户状态
         :param app_id：应用标识
         :param act_id：活动标识
-        :param user_id：用户标识
+        :param user_code：用户标识
         :param user_state：用户状态（0正常1黑名单）
         :return: 
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id"))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
-        user_state = int(self.get_param("user_state"))
+        user_state = self.get_param_int("user_state")
         user_base_model = UserBaseModel(context=self)
         invoke_result_data = user_base_model.update_user_state(app_id, act_id, user_id, user_state)
         if invoke_result_data.success == False:
@@ -102,18 +102,18 @@ class UpdateUserStatusByBlackHandler(ClientBaseHandler):
     """
     :description: 用户拉入黑名单(黑名单管理模式)
     """
-    @filter_check_params("act_id,tb_user_id")
+    @filter_check_params(check_user_code=True)
     def get_async(self):
         """
         :description: 用户拉入黑名单
         :param app_id：应用标识
         :param act_id：活动标识
-        :param tb_user_id：用户标识
+        :param user_code：用户标识
         :return: 
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id"))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
@@ -185,14 +185,13 @@ class UserBlackListHandler(ClientBaseHandler):
     """
     :description: 获取黑名单管理列表
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 获取黑名单管理列表
         :param app_id：应用标识
         :param act_id：活动标识
         :param audit_status：审核状态(0黑名单1申请中2同意3拒绝)
-        :param user_id：用户标识
+        :param user_code：用户标识
         :param start_date：开始时间
         :param end_date：结束时间
         :param nick_name：用户昵称
@@ -203,7 +202,7 @@ class UserBlackListHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         audit_status = int(self.get_param("audit_status", -1))
         user_id = self.get_user_id()
         user_nick = self.get_param("nick_name")
@@ -221,13 +220,13 @@ class UpdateUserAssetHandler(ClientBaseHandler):
     """
     :description: 变更资产
     """
-    @filter_check_params("act_id,tb_user_id,asset_type,asset_value")
+    @filter_check_params("asset_type,asset_value",check_user_code=True)
     def post_async(self):
         """
         :description: 变更资产
         :param app_id：应用标识
         :param act_id：活动标识
-        :param user_id：用户标识
+        :param user_code：用户标识
         :param asset_type：资产类型
         :param asset_value：变更的资产值
         :param asset_object_id：资产对象标识
@@ -235,7 +234,7 @@ class UpdateUserAssetHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         asset_type = int(self.get_param("asset_type", 0))
         asset_value = int(self.get_param("asset_value", 0))
@@ -263,19 +262,19 @@ class BatchUpdateUserAssetHandler(ClientBaseHandler):
     """
     :description: 批量变更资产
     """
-    @filter_check_params("act_id,tb_user_id,asset_object_json")
+    @filter_check_params("asset_object_json",check_user_code=True)
     def post_async(self):
         """
         :description: 批量变更资产
         :param app_id：应用标识
         :param act_id：活动标识
-        :param user_id：用户标识
+        :param user_code：用户标识
         :param asset_object_json：变更的资产值列表
         :return: response_json_success
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         #{"asset_type":0,"asset_object_id":"","asset_value":0}
         asset_object_json = self.get_param("asset_object_json")
@@ -304,21 +303,20 @@ class UserAssetListHandler(ClientBaseHandler):
     """
     :description: 获取用户资产列表
     """
-    @filter_check_params("act_id,tb_user_id")
+    @filter_check_params(check_user_code=True)
     def get_async(self):
         """
         :description: 获取用户资产列表
         :param act_id：活动标识
-        :param tb_user_id：用户标识
+        :param user_code：用户标识
         :param asset_type：资产类型(1-次数2-积分3-价格档位)
         :return list
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         asset_type = int(self.get_param("asset_type", 0))
-
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
@@ -331,7 +329,6 @@ class AssetLogListHandler(ClientBaseHandler):
     """
     :description: 资产流水记录
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 资产流水记录
@@ -353,7 +350,7 @@ class AssetLogListHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
         user_id = self.get_user_id()
@@ -374,9 +371,9 @@ class AssetLogListHandler(ClientBaseHandler):
         else:
             field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         asset_base_model = AssetBaseModel(context=self)
-        page_info = asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, start_date, end_date, user_nick, user_open_id, source_type, source_object_id, field, is_cache=False, operate_type=operate_type)
+        page_list, total = asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, start_date, end_date, user_nick, user_open_id, source_type, source_object_id, field, is_cache=False, operate_type=operate_type)
         ref_params = {}
-        page_info.data = self.business_process_executed(page_info.data, ref_params)
+        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
         return self.response_json_success(page_info)
 
 
@@ -384,7 +381,6 @@ class UserInfoListHandler(ClientBaseHandler):
     """
     :description: 用户信息列表
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 用户信息列表
@@ -401,7 +397,7 @@ class UserInfoListHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         open_id = self.get_param("user_open_id")
         user_nick = self.get_param("nick_name")
