@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-30 09:22:51
-@LastEditTime: 2022-02-18 10:44:29
+@LastEditTime: 2022-09-16 16:02:46
 @LastEditors: HuangJianYi
 @Description: 排队系统帮助类
 """
@@ -18,6 +18,7 @@ class QueueUpHelper:
     踢人规则2：如果都没有正在办理中，那么取上次办理人退出的时间作为排在第一位人员的开始时间，进行倒计时，没有上次办理人退出时间的话，则取当前第一位人员的入队时间进行倒计时；
     """
     logger_error = Logger.get_logger_by_name("log_error")
+    logger_info = Logger.get_logger_by_name("log_info")
 
     @classmethod
     def _get_zset_name(self, app_id, queue_name):
@@ -365,9 +366,11 @@ class QueueUpHelper:
                             if first_is_process == True and i == 0:
                                 if now_timestamp > hash_value["end_timestamp"]:
                                     is_delete = True
+                                    self.logger_info.info("【踢掉办理用户1】" + SevenHelper.json_dumps({"zset_name": zset_name, "user_id": data, "now_timestamp": now_timestamp, "pop_timestamp": hash_value["end_timestamp"]}))
                             elif first_is_process == True and i > 0:
                                 if now_timestamp > first_end_timestamp + (i * int(config.get_value("queue_confirm_time", 8))):
                                     is_delete = True
+                                    self.logger_info.info("【踢掉办理用户2】" + SevenHelper.json_dumps({"zset_name": zset_name, "user_id": data, "now_timestamp": now_timestamp, "pop_timestamp": first_end_timestamp + (i * int(config.get_value("queue_confirm_time", 8)))}))
                             else:
                                 pop_timestamp = redis_init.hget(self._get_popdate_hash_name(app_id), zset_name)
                                 if pop_timestamp:
@@ -376,6 +379,7 @@ class QueueUpHelper:
                                     pop_timestamp = hash_value["queue_timestamp"]
                                 if now_timestamp > pop_timestamp + ((i + 1) * int(config.get_value("queue_confirm_time", 8))):
                                     is_delete = True
+                                    self.logger_info.info("【踢掉办理用户3】" + SevenHelper.json_dumps({"zset_name": zset_name, "user_id": data, "now_timestamp": now_timestamp, "pop_timestamp": pop_timestamp + ((i + 1) * int(config.get_value("queue_confirm_time", 8)))}))
 
                         if is_delete == True:
                             self._set_last_pop_date(app_id, redis_init, zset_name)
@@ -607,6 +611,18 @@ class QueueUpHelper:
         """
         invoke_result_data = InvokeResultData()
         try:
+            acquire_lock_name = f"queueup_sign"
+            if app_id:
+                acquire_lock_name += "_" + str(app_id)
+            acquire_lock_name += ":" + str(queue_name)
+            acquire_lock_name += ":" + str(user_id)
+            acquire_lock_status, identifier = SevenHelper.redis_acquire_lock(acquire_lock_name)
+            if acquire_lock_status == False:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "acquire_lock"
+                invoke_result_data.error_message = "系统繁忙,请稍后再试"
+                return invoke_result_data
+
             redis_init = SevenHelper.redis_init()
             zset_name = self._get_zset_name(app_id, queue_name)
             data = str(user_id)
@@ -615,6 +631,7 @@ class QueueUpHelper:
             if score:
                 queue_index = int(redis_init.zrank(zset_name, data)) + 1  #当前位置
                 if queue_index != 1:
+                    SevenHelper.redis_release_lock(acquire_lock_name, identifier)
                     invoke_result_data.success = False
                     invoke_result_data.error_code = "error"
                     invoke_result_data.error_message = "前面还有人在排队,请耐心等待"
@@ -625,12 +642,14 @@ class QueueUpHelper:
                 hash_key = f"userid_{data}_queuename_{queue_name}"
                 hash_value = redis_init.hget(hash_name, hash_key)
                 if not hash_value:
+                    SevenHelper.redis_release_lock(acquire_lock_name, identifier)
                     invoke_result_data.success = False
                     invoke_result_data.error_code = "error"
                     invoke_result_data.error_message = "未查到排队情况,请先排队"
                     return invoke_result_data
                 hash_value = SevenHelper.json_loads(hash_value)
                 if hash_value["progress_status"] == 2:
+                    SevenHelper.redis_release_lock(acquire_lock_name, identifier)
                     invoke_result_data.success = False
                     invoke_result_data.error_code = "error"
                     invoke_result_data.error_message = "已签到,不能重复签到"
@@ -651,14 +670,17 @@ class QueueUpHelper:
                             continue
                         self.pop(app_id, hash_value["queue_name"], data)
                 invoke_result_data.data = hash_value
+                SevenHelper.redis_release_lock(acquire_lock_name, identifier)
                 return invoke_result_data
             else:
+                SevenHelper.redis_release_lock(acquire_lock_name, identifier)
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
                 invoke_result_data.error_message = "未查到排队情况,请先排队"
                 return invoke_result_data
         except Exception as ex:
             self.logger_error.error("【签到操作】" + traceback.format_exc())
+            SevenHelper.redis_release_lock(acquire_lock_name, identifier)
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "未查到排队情况,请先排队"
