@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2022-07-11 15:01:19
+@LastEditTime: 2022-09-26 10:18:59
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -409,7 +409,7 @@ class WeChatHelper:
 
 class WeChatPayRequest(object):
     """
-    :description: 微信支付请求类,配置文件内容 "wechat_pay": {"api_key": "","mch_id": "","certificate_url":""}
+    :description: 微信支付请求类,配置文件内容 "wechat_pay": {"api_key": "","mch_id": "","certificate_url": "","certificate_key_url": ""}
     """
     """配置账号信息"""
     # =======【基本信息设置】=====================================
@@ -421,15 +421,18 @@ class WeChatPayRequest(object):
     api_key = ""
     # 证书地址,证书文件需要在商户后台下载
     certificate_url = ""
+    # 证书key地址
+    certificate_key_url = ""
 
     logger_error = Logger.get_logger_by_name("log_error")
 
-    def __init__(self, app_id="", api_key="", mch_id="", certificate_url=""):
+    def __init__(self, app_id="", api_key="", mch_id="", certificate_url="", certificate_key_url=""):
         pay_config = config.get_value("wechat_pay")
         self.app_id = app_id if app_id else config.get_value("app_id")
         self.api_key = api_key if api_key else pay_config["api_key"]
         self.mch_id = mch_id if mch_id else pay_config["mch_id"]
         self.certificate_url = certificate_url if certificate_url else pay_config["certificate_url"]
+        self.certificate_key_url = certificate_key_url if certificate_key_url else pay_config["certificate_key_url"]
 
     def get_prepay_id(self, unified_order_url, params):
         """
@@ -696,6 +699,68 @@ class WeChatPayRequest(object):
             invoke_result_data.error_message = "查询退款单出现异常"
             return invoke_result_data
 
+    def send_red_pack(self, mch_billno, send_name, re_openid, total_amount, total_num, wishing, client_ip, act_name, remark, scene_id=''):
+        """
+        :description: 发现金红包(https://pay.weixin.qq.com/wiki/doc/api/tools/cash_coupon.php?chapter=13_4&index=3)
+        :param mch_billno：商户订单号(每个订单号必须唯一组成：mch_id+yyyymmdd+10位一天内不能重复的数字)
+        :param send_name：商户名称(红包发送者名称)
+        :param re_openid：接受红包的用户openid
+        :param total_amount：付款金额，单位分
+        :param total_num：红包发放总人数
+        :param wishing：红包祝福语
+        :param client_ip：该IP可传用户端或者服务端的IP
+        :param act_name：活动名称
+        :param remark：备注信息
+        :param scene_id：发放红包使用场景，红包金额大于200或者小于1元时必传（PRODUCT_1:商品促销PRODUCT_2:抽奖PRODUCT_3:虚拟物品兑奖 PRODUCT_4:企业内部福利PRODUCT_5:渠道分润PRODUCT_6:保险回馈PRODUCT_7:彩票派奖PRODUCT_8:税务刮奖）
+        :return: 当返回错误码为“SYSTEMERROR”时，请不要更换商户订单号，一定要使用原商户订单号重试，否则可能造成重复发放红包等资金风险
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        client_ip = client_ip if SevenHelper.is_ip(client_ip) == True else "127.0.0.1"
+        request_xml = ""
+        try:
+            params = {
+                'appid': self.app_id,
+                'mch_id': self.mch_id,
+                'nonce_str': WeChatHelper.get_nonce_str(),
+                'mch_billno': str(mch_billno),
+                'send_name': send_name,
+                're_openid': re_openid,
+                'total_amount': total_amount,
+                'total_num': total_num,
+                'wishing': wishing,
+                'client_ip': client_ip,
+                'act_name': act_name,
+                'remark': remark
+            }
+            if scene_id:
+                params['scene_id'] = scene_id
+            params['sign'] = WeChatHelper.get_sign(params, self.api_key)
+            request_xml = self.convert_request_xml(params)
+            requset_url = 'https://api.mch.weixin.qq.com/mmpaymkttransfers/sendredpack'
+            # 重点是`cert=(certificate_url, certificate_key_url), verify=True`参数，查看源码后才知道是这样传ca证书
+            respone = requests.post(requset_url, data=request_xml, cert=(self.certificate_url, self.certificate_key_url), verify=True)
+            response_data = xmltodict.parse(respone.text.encode('ISO-8859-1').decode('utf-8'))['xml']
+            if response_data['return_code'] == 'SUCCESS':
+                if response_data['result_code'] == 'SUCCESS':
+                    invoke_result_data.data = {"send_listid": response_data['send_listid']}
+                    return invoke_result_data
+                else:
+                    self.logger_error.error("【发现金红包】" + str(response_data))
+                    invoke_result_data.success = False
+                    invoke_result_data.error_code="error"
+                    invoke_result_data.error_message = response_data['err_code_des']
+                    return invoke_result_data
+            invoke_result_data.data = response_data
+            return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error("【发现金红包】" + traceback.format_exc() + ":" + str(request_xml))
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message = "发现金红包出现异常"
+            return invoke_result_data
+
+
     def convert_request_xml(self, params):
         """
         :description:拼接XML
