@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:26:29
-@LastEditTime: 2022-07-06 18:01:17
+@LastEditTime: 2022-07-15 14:02:30
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -30,7 +30,7 @@ class PriceBaseModel():
         :return: 
         :last_editors: HuangJianYi
         """
-        PriceGearModel().delete_dependency_key(f"price_gear_list:actid_{act_id}", delay_delete_time)
+        PriceGearModel().delete_dependency_key(DependencyKey.price_gear_list(act_id), delay_delete_time)
 
     def save_price_gear(self,app_id,act_id,price_gear_id,relation_type,price_gear_name,price_gear_pic,price,goods_id,sku_id,remark="",sort_index=0):
         """
@@ -147,7 +147,7 @@ class PriceBaseModel():
         params = [app_id,act_id]
         price_gear_model = PriceGearModel(context=self.context)
         if is_cache == True:
-            page_list, total = price_gear_model.get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,dependency_key=f"price_gear_list:actid_{act_id}")
+            page_list, total = price_gear_model.get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,dependency_key=DependencyKey.price_gear_list(act_id))
         else:
             page_list, total = price_gear_model.get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params)
         return page_list, total
